@@ -1,5 +1,3 @@
-/* $Id: swap.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -38,7 +36,7 @@ static const unsigned long _glibtop_sysdeps_swap =
 /* Init function. */
 
 void
-glibtop_init_swap_s (glibtop *server)
+_glibtop_init_swap_s (glibtop *server)
 {
 	server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
