@@ -1,5 +1,3 @@
-/* $Id: procstate.c,v 1.9 2004/06/09 18:52:22 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procstate.h>
@@ -32,7 +31,7 @@ static const unsigned long _glibtop_sysdeps_proc_state = 0;
 /* Init function. */
 
 void
-glibtop_init_proc_state_p (glibtop *server)
+_glibtop_init_proc_state_p (glibtop *server)
 {
 	server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
 }
